==> tuia-advert-center-api-2.0.1-sources.jar: cn/com/duiba/tuia/core/api/dto/app/AppPackageRegularDto.java <==
package cn.com.duiba.tuia.core.api.dto.app;

import io.swagger.annotations.ApiModelProperty;
import org.apache.commons.lang.builder.ToStringBuilder;

import java.io.Serializable;
import java.util.Date;
import java.util.List;

public class AppPackageRegularDto implements Serializable {


    private static final long serialVersionUID = -8130156164840938624L;

    private Long appId;

    private List<Long> appIds;

    //广告类型 1-互动广告，2-展示广告
    private Integer advertType;

    //应用标签:行业标签
    private String appTagTrade;

    //应用标签:流量标签
    private String appTagFlow;

    //应用来源 0-兑吧，1-推啊
    private Integer appSource;

    //操作系统 android，ios
    private String  operationSys;

    //广告行业
    private String  advertTrade;

    //当前日期
    private Date     curDate;

    //开始时间
    private Date startDate;

    //结束时间
    private Date endDate;

    //发券 连续-0,日均-1;大于-0,小于-1"
    // vouchour:["0","1","30"]
    private List<String> vouchour;

    //曝光
    private List<String>  exposure;

    //消费
    private List<String>  consumer;

    //点击
    private List<String>  click;

    //ctr
    private List<String>  ctr;

    //cvr
    private List<String> cvr;

    //cpc
    private List<String>  cpc;

    //arpu
    private List<String>  arpu;

    //落地页pv
    private List<String>   pv;

    //转化成本
    private List<String>   transCost;

    //百奇消耗
    private List<String>  baiqiConsume;

    //百奇下单数
    private List<String>   booking;

    //百奇出单量
    private List<String>   orderCount;

    //出单率
    private List<String>   orderRate;

    //签收量
    private List<String>   signCount;

    //签收率
    private List<String>   signRate;

    //签收成本
    private List<String>    signCost;

    //10天前百奇消耗
    private List<String>         tenDayBaiqiConsume;

    //10天前下单数
    private List<String>          tenDayBaiqiBooking;

    //10天前出单数
    private List<String>          tenDayOrderCount;

    //10天前出单率
    private List<String>           tenDayOrderRate;

    //10天前的签收数
    private List<String>           tenDaySignCount;

    //10天前的签收率
    private List<String>            tenDaySignRate;

    //10天前的签收成本
    private List<String>            tenDaySignCost;

    public Integer getAdvertType() {
        return advertType;
    }

    public void setAdvertType(Integer advertType) {
        this.advertType = advertType;
    }

    public String getAppTagTrade() {
        return appTagTrade;
    }

    public void setAppTagTrade(String appTagTrade) {
        this.appTagTrade = appTagTrade;
    }

    public String getAppTagFlow() {
        return appTagFlow;
    }

    public void setAppTagFlow(String appTagFlow) {
        this.appTagFlow = appTagFlow;
    }

    public Integer getAppSource() {
        return appSource;
    }

    public void setAppSource(Integer appSource) {
        this.appSource = appSource;
    }

    public String getOperationSys() {
        return operationSys;
    }

    public void setOperationSys(String operationSys) {
        this.operationSys = operationSys;
    }

    public List<String> getVouchour() {
        return vouchour;
    }

    public void setVouchour(List<String> vouchour) {
        this.vouchour = vouchour;
    }

    public List<String> getExposure() {
        return exposure;
    }

    public void setExposure(List<String> exposure) {
        this.exposure = exposure;
    }

    public List<String> getConsumer() {
        return consumer;
    }

    public void setConsumer(List<String> consumer) {
        this.consumer = consumer;
    }

    public List<String> getClick() {
        return click;
    }

    public void setClick(List<String> click) {
        this.click = click;
    }

    public List<String> getCtr() {
        return ctr;
    }

    public void setCtr(List<String> ctr) {
        this.ctr = ctr;
    }

    public List<String> getCvr() {
        return cvr;
    }

    public void setCvr(List<String> cvr) {
        this.cvr = cvr;
    }

    public List<String> getCpc() {
        return cpc;
    }

    public void setCpc(List<String> cpc) {
        this.cpc = cpc;
    }

    public List<String> getArpu() {
        return arpu;
    }

    public void setArpu(List<String> arpu) {
        this.arpu = arpu;
    }

    public List<String> getPv() {
        return pv;
    }

    public void setPv(List<String> pv) {
        this.pv = pv;
    }

    public List<String> getTransCost() {
        return transCost;
    }

    public void setTransCost(List<String> transCost) {
        this.transCost = transCost;
    }

    public List<String> getBooking() {
        return booking;
    }

    public void setBooking(List<String> booking) {
        this.booking = booking;
    }

    public List<String> getOrderCount() {
        return orderCount;
    }

    public void setOrderCount(List<String> orderCount) {
        this.orderCount = orderCount;
    }

    public List<String> getOrderRate() {
        return orderRate;
    }

    public void setOrderRate(List<String> orderRate) {
        this.orderRate = orderRate;
    }

    public List<String> getSignCount() {
        return signCount;
    }

    public void setSignCount(List<String> signCount) {
        this.signCount = signCount;
    }

    public List<String> getSignRate() {
        return signRate;
    }

    public void setSignRate(List<String> signRate) {
        this.signRate = signRate;
    }

    public List<String> getSignCost() {
        return signCost;
    }

    public void setSignCost(List<String> signCost) {
        this.signCost = signCost;
    }

    public Long getAppId() {
        return appId;
    }

    public void setAppId(Long appId) {
        this.appId = appId;
    }

    public String getAdvertTrade() {
        return advertTrade;
    }

    public void setAdvertTrade(String advertTrade) {
        this.advertTrade = advertTrade;
    }

    public Date getStartDate() {
        return startDate;
    }

    public void setStartDate(Date startDate) {
        this.startDate = startDate;
    }

    public Date getEndDate() {
        return endDate;
    }

    public void setEndDate(Date endDate) {
        this.endDate = endDate;
    }

    public Date getCurDate() {
        return curDate;
    }

    public void setCurDate(Date curDate) {
        this.curDate = curDate;
    }

    public List<String> getTenDayBaiqiConsume() {
        return tenDayBaiqiConsume;
    }

    public void setTenDayBaiqiConsume(List<String> tenDayBaiqiConsume) {
        this.tenDayBaiqiConsume = tenDayBaiqiConsume;
    }

    public List<String> getTenDayBaiqiBooking() {
        return tenDayBaiqiBooking;
    }

    public void setTenDayBaiqiBooking(List<String> tenDayBaiqiBooking) {
        this.tenDayBaiqiBooking = tenDayBaiqiBooking;
    }

    public List<String> getTenDayOrderCount() {
        return tenDayOrderCount;
    }

    public void setTenDayOrderCount(List<String> tenDayOrderCount) {
        this.tenDayOrderCount = tenDayOrderCount;
    }

    public List<String> getTenDayOrderRate() {
        return tenDayOrderRate;
    }

    public void setTenDayOrderRate(List<String> tenDayOrderRate) {
        this.tenDayOrderRate = tenDayOrderRate;
    }

    public List<String> getTenDaySignCount() {
        return tenDaySignCount;
    }

    public void setTenDaySignCount(List<String> tenDaySignCount) {
        this.tenDaySignCount = tenDaySignCount;
    }

    public List<String> getTenDaySignRate() {
        return tenDaySignRate;
    }

    public void setTenDaySignRate(List<String> tenDaySignRate) {
        this.tenDaySignRate = tenDaySignRate;
    }

    public List<String> getTenDaySignCost() {
        return tenDaySignCost;
    }

    public void setTenDaySignCost(List<String> tenDaySignCost) {
        this.tenDaySignCost = tenDaySignCost;
    }

    public List<String> getBaiqiConsume() {
        return baiqiConsume;
    }

    public void setBaiqiConsume(List<String> baiqiConsume) {
        this.baiqiConsume = baiqiConsume;
    }

    public List<Long> getAppIds() {
        return appIds;
    }

    public void setAppIds(List<Long> appIds) {
        this.appIds = appIds;
    }

    @Override
    public String toString() {
        return ToStringBuilder.reflectionToString(this);
    }
}

==> tuia-advert-center-api-2.5.62-sources.jar: cn/com/duiba/tuia/core/api/dto/app/AppPackageRegularDto.java <==
package cn.com.duiba.tuia.core.api.dto.app;

import org.apache.commons.lang.builder.ToStringBuilder;

import java.io.Serializable;
import java.util.Date;
import java.util.List;

public class AppPackageRegularDto implements Serializable {


    private static final long serialVersionUID = -8130156164840938624L;

    private Long appId;

    private List<Long> appIds;

    //广告类型 1-互动广告，2-展示广告
    private Integer advertType;

    //应用标签:行业标签
    private String appTagTrade;

    //应用标签:流量标签
    private String appTagFlow;

    //应用来源 0-兑吧，1-推啊
    private Integer appSource;

    //操作系统 android，ios
    private String  operationSys;

    //广告行业
    private String  advertTrade;

    //当前日期
    private Date     curDate;

    //开始时间
    private Date startDate;

    //结束时间
    private Date endDate;

    //发券 连续-0,日均-1;大于-0,小于-1"
    // vouchour:["0","1","30"]
    private List<String> vouchour;

    //曝光
    private List<String>  exposure;

    //消费
    private List<String>  consumer;

    //点击
    private List<String>  click;

    //ctr
    private List<String>  ctr;

    //cvr
    private List<String> cvr;

    //cpc
    private List<String>  cpc;

    //arpu
    private List<String>  arpu;

    //落地页pv
    private List<String>   pv;

    //转化成本
    private List<String>   transCost;

    //百奇消耗
    private List<String>  baiqiConsume;

    //百奇下单数
    private List<String>   booking;

    //百奇出单量
    private List<String>   orderCount;

    //出单率
    private List<String>   orderRate;

    //签收量
    private List<String>   signCount;

    //签收率
    private List<String>   signRate;

    //签收成本
    private List<String>    signCost;

    //10天前百奇消耗
    private List<String>         tenDayBaiqiConsume;

    //10天前下单数
    private List<String>          tenDayBaiqiBooking;

    //10天前出单数
    private List<String>          tenDayOrderCount;

    //10天前出单率
    private List<String>           tenDayOrderRate;

    //10天前的签收数
    private List<String>           tenDaySignCount;

    //10天前的签收率
    private List<String>            tenDaySignRate;

    //10天前的签收成本
    private List<String>            tenDaySignCost;

    //注册率(注册/落地页转化)
    private List<String>            registerRateLand;

    //注册率(注册/计费点击)
    private List<String>            registerRateClick;

    //注册成本(消耗/注册)
    private List<String>            registerCost;

    //激活率(激活/落地页转化)
    private List<String>            activateRateLand;

    //激活率(激活/计费点击)
    private List<String>            activateRateClick;

    //激活成本(消耗/激活)
    private List<String>            activateCost;



    //作弊占比(这项子标是新需求迭代的 在一张新的表里 和前面的指标取值逻辑不一样 )  cheatRatio:["50","80","7"]  50-70区间范围 7代表查询数据周期7天
    //http://cf.dui88.com/pages/viewpage.action?pageId=140415637
    //http://cf.dui88.com/pages/viewpage.action?pageId=141496704需求迭代
    private List<String> cheatRatio;

    public List<String> getCheatRatio() {
        return cheatRatio;
    }

    public void setCheatRatio(List<String> cheatRatio) {
        this.cheatRatio = cheatRatio;
    }

    public Integer getAdvertType() {
        return advertType;
    }

    public void setAdvertType(Integer advertType) {
        this.advertType = advertType;
    }

    public String getAppTagTrade() {
        return appTagTrade;
    }

    public void setAppTagTrade(String appTagTrade) {
        this.appTagTrade = appTagTrade;
    }

    public String getAppTagFlow() {
        return appTagFlow;
    }

    public void setAppTagFlow(String appTagFlow) {
        this.appTagFlow = appTagFlow;
    }

    public Integer getAppSource() {
        return appSource;
    }

    public void setAppSource(Integer appSource) {
        this.appSource = appSource;
    }

    public String getOperationSys() {
        return operationSys;
    }

    public void setOperationSys(String operationSys) {
        this.operationSys = operationSys;
    }

    public List<String> getVouchour() {
        return vouchour;
    }

    public void setVouchour(List<String> vouchour) {
        this.vouchour = vouchour;
    }

    public List<String> getExposure() {
        return exposure;
    }

    public void setExposure(List<String> exposure) {
        this.exposure = exposure;
    }

    public List<String> getConsumer() {
        return consumer;
    }

    public void setConsumer(List<String> consumer) {
        this.consumer = consumer;
    }

    public List<String> getClick() {
        return click;
    }

    public void setClick(List<String> click) {
        this.click = click;
    }

    public List<String> getCtr() {
        return ctr;
    }

    public void setCtr(List<String> ctr) {
        this.ctr = ctr;
    }

    public List<String> getCvr() {
        return cvr;
    }

    public void setCvr(List<String> cvr) {
        this.cvr = cvr;
    }

    public List<String> getCpc() {
        return cpc;
    }

    public void setCpc(List<String> cpc) {
        this.cpc = cpc;
    }

    public List<String> getArpu() {
        return arpu;
    }

    public void setArpu(List<String> arpu) {
        this.arpu = arpu;
    }

    public List<String> getPv() {
        return pv;
    }

    public void setPv(List<String> pv) {
        this.pv = pv;
    }

    public List<String> getTransCost() {
        return transCost;
    }

    public void setTransCost(List<String> transCost) {
        this.transCost = transCost;
    }

    public List<String> getBooking() {
        return booking;
    }

    public void setBooking(List<String> booking) {
        this.booking = booking;
    }

    public List<String> getOrderCount() {
        return orderCount;
    }

    public void setOrderCount(List<String> orderCount) {
        this.orderCount = orderCount;
    }

    public List<String> getOrderRate() {
        return orderRate;
    }

    public void setOrderRate(List<String> orderRate) {
        this.orderRate = orderRate;
    }

    public List<String> getSignCount() {
        return signCount;
    }

    public void setSignCount(List<String> signCount) {
        this.signCount = signCount;
    }

    public List<String> getSignRate() {
        return signRate;
    }

    public void setSignRate(List<String> signRate) {
        this.signRate = signRate;
    }

    public List<String> getSignCost() {
        return signCost;
    }

    public void setSignCost(List<String> signCost) {
        this.signCost = signCost;
    }

    public Long getAppId() {
        return appId;
    }

    public void setAppId(Long appId) {
        this.appId = appId;
    }

    public String getAdvertTrade() {
        return advertTrade;
    }

    public void setAdvertTrade(String advertTrade) {
        this.advertTrade = advertTrade;
    }

    public Date getStartDate() {
        return startDate;
    }

    public void setStartDate(Date startDate) {
        this.startDate = startDate;
    }

    public Date getEndDate() {
        return endDate;
    }

    public void setEndDate(Date endDate) {
        this.endDate = endDate;
    }

    public Date getCurDate() {
        return curDate;
    }

    public void setCurDate(Date curDate) {
        this.curDate = curDate;
    }

    public List<String> getTenDayBaiqiConsume() {
        return tenDayBaiqiConsume;
    }

    public void setTenDayBaiqiConsume(List<String> tenDayBaiqiConsume) {
        this.tenDayBaiqiConsume = tenDayBaiqiConsume;
    }

    public List<String> getTenDayBaiqiBooking() {
        return tenDayBaiqiBooking;
    }

    public void setTenDayBaiqiBooking(List<String> tenDayBaiqiBooking) {
        this.tenDayBaiqiBooking = tenDayBaiqiBooking;
    }

    public List<String> getTenDayOrderCount() {
        return tenDayOrderCount;
    }

    public void setTenDayOrderCount(List<String> tenDayOrderCount) {
        this.tenDayOrderCount = tenDayOrderCount;
    }

    public List<String> getTenDayOrderRate() {
        return tenDayOrderRate;
    }

    public void setTenDayOrderRate(List<String> tenDayOrderRate) {
        this.tenDayOrderRate = tenDayOrderRate;
    }

    public List<String> getTenDaySignCount() {
        return tenDaySignCount;
    }

    public void setTenDaySignCount(List<String> tenDaySignCount) {
        this.tenDaySignCount = tenDaySignCount;
    }

    public List<String> getTenDaySignRate() {
        return tenDaySignRate;
    }

    public void setTenDaySignRate(List<String> tenDaySignRate) {
        this.tenDaySignRate = tenDaySignRate;
    }

    public List<String> getTenDaySignCost() {
        return tenDaySignCost;
    }

    public void setTenDaySignCost(List<String> tenDaySignCost) {
        this.tenDaySignCost = tenDaySignCost;
    }

    public List<String> getBaiqiConsume() {
        return baiqiConsume;
    }

    public void setBaiqiConsume(List<String> baiqiConsume) {
        this.baiqiConsume = baiqiConsume;
    }

    public List<Long> getAppIds() {
        return appIds;
    }

    public void setAppIds(List<Long> appIds) {
        this.appIds = appIds;
    }

    public List<String> getRegisterRateLand() {
        return registerRateLand;
    }

    public void setRegisterRateLand(List<String> registerRateLand) {
        this.registerRateLand = registerRateLand;
    }

    public List<String> getRegisterRateClick() {
        return registerRateClick;
    }

    public void setRegisterRateClick(List<String> registerRateClick) {
        this.registerRateClick = registerRateClick;
    }

    public List<String> getRegisterCost() {
        return registerCost;
    }

    public void setRegisterCost(List<String> registerCost) {
        this.registerCost = registerCost;
    }

    public List<String> getActivateRateLand() {
        return activateRateLand;
    }

    public void setActivateRateLand(List<String> activateRateLand) {
        this.activateRateLand = activateRateLand;
    }

    public List<String> getActivateRateClick() {
        return activateRateClick;
    }

    public void setActivateRateClick(List<String> activateRateClick) {
        this.activateRateClick = activateRateClick;
    }

    public List<String> getActivateCost() {
        return activateCost;
    }

    public void setActivateCost(List<String> activateCost) {
        this.activateCost = activateCost;
    }

    @Override
    public String toString() {
        return ToStringBuilder.reflectionToString(this);
    }
}
